==> qt-creator-opensource-src-3.0.0.zip: qt-creator-opensource-src-3.0.0/src/plugins/qmldesigner/components/formeditor/anchorindicatorgraphicsitem.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLDESIGNER_ANCHORINDICATORGRAPHICSITEM_H
#define QMLDESIGNER_ANCHORINDICATORGRAPHICSITEM_H

#include <QGraphicsObject>

#include <qmlanchors.h>

namespace QmlDesigner {

class AnchorIndicatorGraphicsItem : public QGraphicsObject
{
    Q_OBJECT
public:
    explicit AnchorIndicatorGraphicsItem(QGraphicsItem *parent = 0);


    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
    QRectF boundingRect() const;

    void updateAnchorIndicator(const AnchorLine &sourceAnchorLine, const AnchorLine targetAnchorLine);

    AnchorLine::Type sourceAnchorLineType() const;
    void setSourceAnchorLineType(const AnchorLine::Type &sourceAnchorLineType);

protected:
    void updateBoundingRect();

private:
    QPointF m_startPoint;
    QPointF m_firstControlPoint;
    QPointF m_secondControlPoint;
    QPointF m_endPoint;
    QPointF m_sourceAnchorLineFirstPoint;
    QPointF m_sourceAnchorLineSecondPoint;
    QPointF m_targetAnchorLineFirstPoint;
    QPointF m_targetAnchorLineSecondPoint;
    AnchorLine::Type m_sourceAnchorLineType;
    AnchorLine::Type m_targetAnchorLineType;
    QRectF m_boundingRect;
};

} // namespace QmlDesigner

#endif // QMLDESIGNER_ANCHORINDICATORGRAPHICSITEM_H

==> qt-creator-opensource-src-3.2.2.zip: qt-creator-opensource-src-3.2.2/src/plugins/qmldesigner/components/formeditor/anchorindicatorgraphicsitem.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#ifndef QMLDESIGNER_ANCHORINDICATORGRAPHICSITEM_H
#define QMLDESIGNER_ANCHORINDICATORGRAPHICSITEM_H

#include <QGraphicsObject>

#include <qmlanchors.h>

namespace QmlDesigner {

class AnchorIndicatorGraphicsItem : public QGraphicsObject
{
    Q_OBJECT
public:
    explicit AnchorIndicatorGraphicsItem(QGraphicsItem *parent = 0);


    void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
    QRectF boundingRect() const;

    void updateAnchorIndicator(const AnchorLine &sourceAnchorLine, const AnchorLine &targetAnchorLine);

    AnchorLineType sourceAnchorLineType() const;
    void setSourceAnchorLineType(const AnchorLineType &sourceAnchorLineType);

protected:
    void updateBoundingRect();

private:
    QPointF m_startPoint;
    QPointF m_firstControlPoint;
    QPointF m_secondControlPoint;
    QPointF m_endPoint;
    QPointF m_sourceAnchorLineFirstPoint;
    QPointF m_sourceAnchorLineSecondPoint;
    QPointF m_targetAnchorLineFirstPoint;
    QPointF m_targetAnchorLineSecondPoint;
    AnchorLineType m_sourceAnchorLineType;
    AnchorLineType m_targetAnchorLineType;
    QRectF m_boundingRect;
};

} // namespace QmlDesigner

#endif // QMLDESIGNER_ANCHORINDICATORGRAPHICSITEM_H
